Stan Math Library: stan/math/prim/mat/err/check_matching_dims.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
check_matching_dims.hpp File Reference
`#include <stan/math/prim/scal/err/domain_error.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/scal/err/check_size_match.hpp>`
`#include <sstream>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T1 , typename T2 , int R1, int C1, int R2, int C2>
bool | stan::math::check_matching_dims (const char *function, const char *name1, const Eigen::Matrix< T1, R1, C1 > &y1, const char *name2, const Eigen::Matrix< T2, R2, C2 > &y2)
| Return `true` if the two matrices are of the same size. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.